@@ -69,7 +69,7 @@ def getUniqueTokenFromTransactions(connection, schema, public_address:str=None,
 
     return allResults
 
-def getUniqueAddress(connection, schema,chain_id:int=None):
+def getUniqueAddress(connection, schema, chain_id:int=None):
     
     queryStr = "select distinct(public_address) \
         FROM {}.dwh_address_account"
@@ -83,4 +83,32 @@ def getUniqueAddress(connection, schema,chain_id:int=None):
     query = sql.SQL(queryStr).format(sql.Identifier(schema))
 
     result = herokuDbAccess.fetchDataInDatabase(query, params, connection)    
+    return result
+
+def getLatestTx(connection, schema, public_address, min_timestamp):
+    
+    queryStr = "SELECT tx_timestamp, tx_from, amount_fee_value, amount_fee_dwh_token_id,  \
+                        amount_send_value, amount_send_dwh_token_id, \
+                        amount_recv_value, amount_recv_dwh_token_id  \
+                FROM {}.dwh_transaction \
+                WHERE public_address = %s AND tx_timestamp > %s \
+                ORDER BY tx_timestamp DESC"
+  
+    query = sql.SQL(queryStr).format(sql.Identifier(schema))
+
+    result = herokuDbAccess.fetchDataInDatabase(query, [public_address, min_timestamp], connection) 
+    return result
+
+def getTxSortedAsc(connection, schema, public_address):
+
+    queryStr = "SELECT tx_timestamp, tx_from, amount_fee_value, amount_fee_dwh_token_id,  \
+                        amount_send_value, amount_send_dwh_token_id, \
+                        amount_recv_value, amount_recv_dwh_token_id  \
+                FROM {}.dwh_transaction \
+                WHERE public_address = %s \
+                ORDER BY tx_timestamp ASC"
+
+    query = sql.SQL(queryStr).format(sql.Identifier(schema))
+
+    result = herokuDbAccess.fetchDataInDatabase(query, [public_address], connection) 
     return result
\ No newline at end of file
